
---
# UVA click

> PRVIH_PAR_RECENICA_SA_PRODUCT_PAGE_DA_ISPRATE_CELINU

<p align="center">
  <img src="CLICK_IMAGE_LINK" height=300px>
</p>

[click Product page](CLICK_PRODUCT_PAGE_LINK)

---


#### Click library

- **Author**        : Stefan Filipovic
- **Date**          : Dec 2021.
- **Type**          : I2C type


# Software Support

We provide a library for the UVA Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for UVA Click driver.

#### Standard key functions :

- `uva_cfg_setup` Config Object Initialization function.
```c
void uva_cfg_setup ( uva_cfg_t *cfg );
```

- `uva_init` Initialization function.
```c
err_t uva_init ( uva_t *ctx, uva_cfg_t *cfg );
```

- `uva_default_cfg` Click Default Configuration function.
```c
err_t uva_default_cfg ( uva_t *ctx );
```

#### Example key functions :

- `uva_read_data` This function reads the raw UVA data from registers.
```c
err_t uva_read_data ( uva_t *ctx, uint16_t *uva_data );
```

- `uva_soft_reset` This function executes the soft reset command.
```c
err_t uva_soft_reset ( uva_t *ctx );
```

- `uva_write_register` This function writes a data byte to the selected register by using I2C serial interface.
```c
err_t uva_write_register ( uva_t *ctx, uint8_t reg, uint8_t data_in );
```

## Example Description

> This example demonstrates the use of UVA click board by reading and displaying the UVA data measurement results.

**The demo application is composed of two sections :**

### Application Init

> Initializes the driver and applies the click default configuration.

```c

void application_init ( void )
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    uva_cfg_t uva_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    uva_cfg_setup( &uva_cfg );
    UVA_MAP_MIKROBUS( uva_cfg, MIKROBUS_1 );
    if ( I2C_MASTER_ERROR == uva_init( &uva, &uva_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }
    
    if ( UVA_ERROR == uva_default_cfg ( &uva ) )
    {
        log_error( &logger, " Default configuration." );
        for ( ; ; );
    }
    
    log_info( &logger, " Application Task " );
}

```

### Application Task

> Reads the UVA data measurements every 100ms and displays the results on the USB UART.

```c
void application_task ( void )
{
    uint16_t uva_data = 0;
    if ( UVA_OK == uva_read_data ( &uva, &uva_data ) )
    {
        log_printf ( &logger, " UVA data: %u \r\n\n", uva_data );
        Delay_ms ( 100 );
    }
}
```

The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.UVA

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
